# Pytest Jest Report

A custom version of `pytest-json-report` adapted for [jest-pytest](https://github.com/jondot/jest-pytest).

## Installation

```
pip install pytest-jest --upgrade
```

## Usage

For now, use this in combination with [jest-pytest](https://github.com/jondot/jest-pytest)

## Development

* Tests are defunct (not updated)
* Ad-hoc-iness for now, until API solidifies.
